==> guiCrudApi-2.1-sources.jar: org/fryske_akademy/jsf/Filtering.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.fryske_akademy.jsf;

/*-
 * #%L
 * guiCrudApi
 * %%
 * Copyright (C) 2018 Fryske Akademy
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import java.util.List;
import java.util.Map;
import org.fryske_akademy.jpa.AbstractEntity;

/**
 *
 * @author eduard
 */
public interface Filtering<T extends AbstractEntity> {

    /**
     * Use this in primefaces EL expression for filteredValue
     * @return
     */
    List<T> getFiltered();

    /**
     * used this in EL expression for filterValue: #{controller.filters['filtername']}
     * @return
     */
    Map<String, Object> getFilters();

    /**
     *
     * @param key
     * @param value
     * @param maxResults
     */
    void select(String key, String value, int maxResults);

    void setFiltered(List<T> filtered);
    
    void clear();
    
}

==> guiCrudApi-4.7-sources.jar: org/fryske_akademy/jsf/Filtering.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.fryske_akademy.jsf;

/*-
 * #%L
 * guiCrudApi
 * %%
 * Copyright (C) 2018 Fryske Akademy
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import java.util.List;
import java.util.Map;
import org.fryske_akademy.jpa.EntityInterface;

/**
 *
 * @author eduard
 */
public interface Filtering<T extends EntityInterface> {

    /**
     * Use this in primefaces EL expression for filteredValue
     * @return
     */
    List<T> getFiltered();

    /**
     * used this in EL expression for filterValue: #{controller.filters['filtername']}
     * @return
     */
    Map<String, Object> getFilters();

    /**
     *
     * @param key
     * @param value
     * @param maxResults
     */
    void select(String key, String value, int maxResults);

    void setFiltered(List<T> filtered);
    
    void clear();
    
}
